@@ -42,7 +42,7 @@ class HomeAssistantCog(commands.Cog):
     @commands.has_role("Shiny")
     async def tesla(self, context: discord.Interaction, choices: str):
         taylor = ha.TaylorSwiftly()
-        status = getattr(taylor, choices)()
+        status = taylor.get_functions()[choices]()
         await context.response.send_message(f"Taylor Swiftly is {status}")
 
 
